==> bot-0.8.0.tar.gz: lib/src/bot/collection/number_enumerable.dart <==
part of bot;

NumberEnumerable n$(Iterable<num> source) {
  return new NumberEnumerable.from(source);
}

abstract class NumberEnumerable<T extends num> extends Enumerable<T> {

  const NumberEnumerable() : super();

  factory NumberEnumerable.from(Iterable<T> source) {
    requireArgumentNotNull(source, 'source');
    return new _SimpleNumEnumerable<T>(source);
  }

  factory NumberEnumerable.fromRange(int start, int count) {
    return new _RangeEnumerable(start, count);
  }

  num sum() {
    num theSum = 0;
    for(final n in this) {
      if(n == null) {
        throw const InvalidOperationError('Input contained a null item');
      }
      theSum += n;
    }
    return theSum;
  }

  num average() {
    int theCount = 0;
    num theSum = 0;
    for(final n in this) {
      if(n == null) {
        throw const InvalidOperationError('Input contained a null item');
      }
      theSum += n;
      theCount++;
    }
    return theSum / theCount;
  }

  num max() {
    num theMax = null;
    for(final n in this) {
      if(n == null) {
        throw const InvalidOperationError('Input contained a null item');
      }
      theMax = theMax == null ? n : math.max(theMax, n);
    }
    return theMax;
  }

  num min() {
    num theMin = null;
    for(final n in this) {
      if(n == null) {
        throw const InvalidOperationError('Input contained a null item');
      }
      theMin = theMin == null ? n : math.min(theMin, n);
    }
    return theMin;
  }
}

class _SimpleNumEnumerable<T extends num> extends NumberEnumerable<T> {
  final Iterable<T> _source;

  const _SimpleNumEnumerable(this._source) : super();

  Iterator<T> iterator() => _source.iterator();
}

class _FuncNumEnumerable<TSource> extends NumberEnumerable {
  final Iterable<TSource> _source;
  final Func1<Iterator<TSource>, Iterator<num>> _func;

  const _FuncNumEnumerable(this._source, this._func) : super();

  Iterator<num> iterator() => _func(_source.iterator());
}

class _RangeEnumerable extends NumberEnumerable<int> {
  final int _start;
  final int _count;

  const _RangeEnumerable(this._start, this._count);

  Iterator<int> iterator() => new _RangeIterator(_start, _count);
}

class _RangeIterator implements Iterator<int> {
  final int _start;
  final int _count;

  int _current = 0;

  _RangeIterator(this._start, this._count);

  bool get hasNext => _current < _count;

  int next() {
    assert(hasNext);
    final val = _start + _current;
    _current++;
    return val;
  }
}

==> bot-0.14.1.tar.gz: lib/src/bot/collection/number_enumerable.dart <==
part of bot;

NumberEnumerable n$(Iterable<num> source) {
  return new NumberEnumerable.from(source);
}

abstract class NumberEnumerable<T extends num> extends Iterable<T> {

  const NumberEnumerable() : super();

  factory NumberEnumerable.from(Iterable<T> source) {
    requireArgumentNotNull(source, 'source');
    return new _SimpleNumEnumerable<T>(source);
  }

  factory NumberEnumerable.fromRange(int start, int count) {
    return new _RangeEnumerable(start, count);
  }

  num sum() {
    num theSum = 0;
    for(final n in this) {
      if(n == null) {
        throw const InvalidOperationError('Input contained a null item');
      }
      theSum += n;
    }
    return theSum;
  }

  num average() {
    int theCount = 0;
    num theSum = 0;
    for(final n in this) {
      if(n == null) {
        throw const InvalidOperationError('Input contained a null item');
      }
      theSum += n;
      theCount++;
    }
    return theSum / theCount;
  }
}

class _SimpleNumEnumerable<T extends num> extends NumberEnumerable<T> {
  final Iterable<T> _source;

  const _SimpleNumEnumerable(this._source) : super();

  Iterator<T> get iterator => _source.iterator;
}

class _FuncNumEnumerable<TSource> extends NumberEnumerable {
  final Iterable<TSource> _source;
  final Func1<Iterator<TSource>, Iterator<num>> _func;

  const _FuncNumEnumerable(this._source, this._func) : super();

  Iterator<num> get iterator => _func(_source.iterator);
}

class _RangeEnumerable extends NumberEnumerable<int> {
  final int _start;
  final int _count;

  const _RangeEnumerable(this._start, this._count);

  Iterator<int> get iterator => new _RangeIterator(_start, _count);
}

class _RangeIterator implements Iterator<int> {
  final int _start;
  final int _count;
  int _current = null;

  _RangeIterator(this._start, this._count);

  bool moveNext() {
    if(_current == null) {
      _current = _start - 1;
    }

    if(_current < _start + _count - 1) {
      _current++;
      return true;
    } else {
      return false;
    }
  }

  int get current => _current;
}
